import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataKubernetesIngressConfig extends cdktf.TerraformMetaArguments {
    /**
    * metadata block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/ingress#metadata DataKubernetesIngress#metadata}
    */
    readonly metadata: DataKubernetesIngressMetadata;
}
export declare class DataKubernetesIngressSpecBackend extends cdktf.ComplexComputedList {
    get serviceName(): string;
    get servicePort(): string;
}
export declare class DataKubernetesIngressSpecRuleHttpPathBackend extends cdktf.ComplexComputedList {
    get serviceName(): string;
    get servicePort(): string;
}
export declare class DataKubernetesIngressSpecRuleHttpPath extends cdktf.ComplexComputedList {
    get backend(): cdktf.IResolvable;
    get path(): string;
}
export declare class DataKubernetesIngressSpecRuleHttp extends cdktf.ComplexComputedList {
    get path(): cdktf.IResolvable;
}
export declare class DataKubernetesIngressSpecRule extends cdktf.ComplexComputedList {
    get host(): string;
    get http(): cdktf.IResolvable;
}
export declare class DataKubernetesIngressSpecTls extends cdktf.ComplexComputedList {
    get hosts(): string[];
    get secretName(): string;
}
export declare class DataKubernetesIngressSpec extends cdktf.ComplexComputedList {
    get backend(): cdktf.IResolvable;
    get ingressClassName(): string;
    get rule(): cdktf.IResolvable;
    get tls(): cdktf.IResolvable;
}
export declare class DataKubernetesIngressStatusLoadBalancerIngress extends cdktf.ComplexComputedList {
    get hostname(): string;
    get ip(): string;
}
export declare class DataKubernetesIngressStatusLoadBalancer extends cdktf.ComplexComputedList {
    get ingress(): cdktf.IResolvable;
}
export declare class DataKubernetesIngressStatus extends cdktf.ComplexComputedList {
    get loadBalancer(): cdktf.IResolvable;
}
export interface DataKubernetesIngressMetadata {
    /**
    * An unstructured key value map stored with the ingress that may be used to store arbitrary metadata. More info: http://kubernetes.io/docs/user-guide/annotations
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/ingress#annotations DataKubernetesIngress#annotations}
    */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
    * Map of string keys and values that can be used to organize and categorize (scope and select) the ingress. May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/ingress#labels DataKubernetesIngress#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Name of the ingress, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/ingress#name DataKubernetesIngress#name}
    */
    readonly name?: string;
    /**
    * Namespace defines the space within which name of the ingress must be unique.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/ingress#namespace DataKubernetesIngress#namespace}
    */
    readonly namespace?: string;
}
export declare function dataKubernetesIngressMetadataToTerraform(struct?: DataKubernetesIngressMetadataOutputReference | DataKubernetesIngressMetadata): any;
export declare class DataKubernetesIngressMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    get internalValue(): DataKubernetesIngressMetadata | undefined;
    set internalValue(value: DataKubernetesIngressMetadata | undefined);
    private _annotations?;
    get annotations(): {
        [key: string]: string;
    };
    set annotations(value: {
        [key: string]: string;
    });
    resetAnnotations(): void;
    get annotationsInput(): {
        [key: string]: string;
    } | undefined;
    get generation(): number;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    get resourceVersion(): string;
    get uid(): string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/kubernetes/d/ingress kubernetes_ingress}
*/
export declare class DataKubernetesIngress extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/d/ingress kubernetes_ingress} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataKubernetesIngressConfig
    */
    constructor(scope: Construct, id: string, config: DataKubernetesIngressConfig);
    get id(): string;
    spec(index: string): DataKubernetesIngressSpec;
    status(index: string): DataKubernetesIngressStatus;
    private _metadata;
    get metadata(): DataKubernetesIngressMetadataOutputReference;
    putMetadata(value: DataKubernetesIngressMetadata): void;
    get metadataInput(): DataKubernetesIngressMetadata | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
