import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataKubernetesServiceV1Config extends cdktf.TerraformMetaArguments {
    /**
    * metadata block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/service_v1#metadata DataKubernetesServiceV1#metadata}
    */
    readonly metadata: DataKubernetesServiceV1Metadata;
}
export declare class DataKubernetesServiceV1SpecPort extends cdktf.ComplexComputedList {
    get name(): string;
    get nodePort(): number;
    get port(): number;
    get protocol(): string;
    get targetPort(): string;
}
export declare class DataKubernetesServiceV1Spec extends cdktf.ComplexComputedList {
    get clusterIp(): string;
    get externalIps(): string[];
    get externalName(): string;
    get externalTrafficPolicy(): string;
    get healthCheckNodePort(): number;
    get loadBalancerIp(): string;
    get loadBalancerSourceRanges(): string[];
    get port(): cdktf.IResolvable;
    get publishNotReadyAddresses(): cdktf.IResolvable;
    get selector(): {
        [key: string]: string;
    };
    get sessionAffinity(): string;
    get type(): string;
}
export declare class DataKubernetesServiceV1StatusLoadBalancerIngress extends cdktf.ComplexComputedList {
    get hostname(): string;
    get ip(): string;
}
export declare class DataKubernetesServiceV1StatusLoadBalancer extends cdktf.ComplexComputedList {
    get ingress(): cdktf.IResolvable;
}
export declare class DataKubernetesServiceV1Status extends cdktf.ComplexComputedList {
    get loadBalancer(): cdktf.IResolvable;
}
export interface DataKubernetesServiceV1Metadata {
    /**
    * An unstructured key value map stored with the service that may be used to store arbitrary metadata. More info: http://kubernetes.io/docs/user-guide/annotations
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/service_v1#annotations DataKubernetesServiceV1#annotations}
    */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
    * Map of string keys and values that can be used to organize and categorize (scope and select) the service. May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/service_v1#labels DataKubernetesServiceV1#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Name of the service, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/service_v1#name DataKubernetesServiceV1#name}
    */
    readonly name?: string;
    /**
    * Namespace defines the space within which name of the service must be unique.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/service_v1#namespace DataKubernetesServiceV1#namespace}
    */
    readonly namespace?: string;
}
export declare function dataKubernetesServiceV1MetadataToTerraform(struct?: DataKubernetesServiceV1MetadataOutputReference | DataKubernetesServiceV1Metadata): any;
export declare class DataKubernetesServiceV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    get internalValue(): DataKubernetesServiceV1Metadata | undefined;
    set internalValue(value: DataKubernetesServiceV1Metadata | undefined);
    private _annotations?;
    get annotations(): {
        [key: string]: string;
    };
    set annotations(value: {
        [key: string]: string;
    });
    resetAnnotations(): void;
    get annotationsInput(): {
        [key: string]: string;
    } | undefined;
    get generation(): number;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    get resourceVersion(): string;
    get uid(): string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/kubernetes/d/service_v1 kubernetes_service_v1}
*/
export declare class DataKubernetesServiceV1 extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/d/service_v1 kubernetes_service_v1} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataKubernetesServiceV1Config
    */
    constructor(scope: Construct, id: string, config: DataKubernetesServiceV1Config);
    get id(): string;
    spec(index: string): DataKubernetesServiceV1Spec;
    status(index: string): DataKubernetesServiceV1Status;
    private _metadata;
    get metadata(): DataKubernetesServiceV1MetadataOutputReference;
    putMetadata(value: DataKubernetesServiceV1Metadata): void;
    get metadataInput(): DataKubernetesServiceV1Metadata | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
